Package: HCAData
Type: Package
Title: Accessing The Datasets Of The Human Cell Atlas in R/Bioconductor
Version: 1.29.0
Authors@R: c(
    person("Federico","Marini", role=c("aut","cre"), email="marinif@uni-mainz.de",
    comment = c(ORCID = '0000-0003-3252-7758')))
Description: This package allows a direct access to the dataset generated by the 
    Human Cell Atlas project for further processing in R and Bioconductor, in the
    comfortable format of SingleCellExperiment objects
    (available in other formats here: http://preview.data.humancellatlas.org/).
License: MIT + file LICENSE
Encoding: UTF-8
biocViews: RNASeqData, SingleCellData, ExperimentData, ExpressionData,
        ExperimentHub
Depends: R (>= 3.6), SingleCellExperiment
Imports: ExperimentHub, AnnotationHub, HDF5Array, utils
Suggests: knitr, rmarkdown, BiocStyle, scran (>= 1.11.4), BiocSingular,
        scater, scuttle, Rtsne, igraph, iSEE, testthat
URL: https://github.com/federicomarini/HCAData
VignetteBuilder: knitr
RoxygenNote: 7.3.2
Roxygen: list(markdown = TRUE)
git_url: https://git.bioconductor.org/packages/HCAData
git_branch: devel
git_last_commit: b37a62e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 15:42:47 UTC; biocbuild
Author: Federico Marini [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3252-7758>)
Maintainer: Federico Marini <marinif@uni-mainz.de>
