# Generated by roxygen2: do not edit by hand

export(HCAData)
importFrom(AnnotationHub,query)
importFrom(ExperimentHub,ExperimentHub)
importFrom(ExperimentHub,createHubAccessors)
importFrom(HDF5Array,HDF5Array)
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(utils,read.csv)
